function InitLogger(app) {
  app.use((req, res, next) => {
    console.log(`[${(new Date()).toGMTString()}] ${req.method} --> ${req.url}`);
    next();
  });
  return app;
}

function LogError(...vars) {
  console.log.apply(null, ['[ERROR]', ...vars]);
}

/**
 * Display a message on stdout if the ENV is set to "Dev"
 */
function LogDebug(...vars) {
  if (process.env.API_ENV === 'Dev') {
    console.log.apply(null, ['[DEBUG]', ...vars]);
  }
}

/**
 * Set the error status and body.
 * It also log an error on the stdout.
 *
 * ```js
 * try { stuff }
 * catch (err) { return Errors.haltRequest(ctx, 400, { code: 'ERR_BAD_TOKEN', message: 'Bad token (undefined)', stack: err.stack }) }
 * ```
 */
function HaltRequest(res, status = 500, message = { code: 'ERR_GENERIC' }, err = undefined) {
  LogError(message);
  res.status(status);
  if (err) message.stack = err.stack;
  res.json(message);
  return null;
}

module.exports = {
  LogError: LogError,
  LogDebug: LogDebug,
  HaltRequest: HaltRequest,
  InitLogger: InitLogger,
};
